@@ -1,7 +1,7 @@
 #==============================================================================
 # Contains some Tk option database settings.
 #
-# Copyright (c) 2004-2014  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2004-2016  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
 #
@@ -36,7 +36,7 @@ if {[string compare $winSys "x11"] == 0} {
     option add *ScrollArea.Text.highlightThickness	0
 }
 option add *Tablelist.background	white
-option add *Tablelist.stripeBackground	#e4e8ec
+option add *Tablelist.stripeBackground	#f0f0f0
 option add *Tablelist.setGrid		yes
 option add *Tablelist.movableColumns	yes
 option add *Tablelist.labelCommand	tablelist::sortByColumn
