@@ -7,7 +7,7 @@
 #   - Private procedures implementing the interactive cell editing
 #   - Private procedures used in bindings related to interactive cell editing
 #
-# Copyright (c) 2003-2014  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2003-2016  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
 #
@@ -21,8 +21,10 @@ namespace eval tablelist {
     # menubutton, and spinbox for interactive cell editing
     #
     proc addTkCoreWidgets {} {
+	variable editWin
+
 	set name entry
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"$name %W -width 0" \
 	    $name-putValueCmd	"%W delete 0 end; %W insert 0 %T" \
 	    $name-getValueCmd	"%W get" \
@@ -42,7 +44,7 @@ namespace eval tablelist {
 	]
 
 	set name text
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"$name %W -padx 2 -pady 2 -wrap none" \
 	    $name-putValueCmd	"%W delete 1.0 end; %W insert 1.0 %T" \
 	    $name-getValueCmd	"%W get 1.0 end-1c" \
@@ -64,7 +66,7 @@ namespace eval tablelist {
 	]
 
 	set name checkbutton
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createCheckbutton %W" \
 	    $name-putValueCmd	{set [%W cget -variable] %T} \
 	    $name-getValueCmd	{set [%W cget -variable]} \
@@ -84,7 +86,7 @@ namespace eval tablelist {
 	]
 
 	set name menubutton
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createMenubutton %W" \
 	    $name-putValueCmd	{set [%W cget -textvariable] %T} \
 	    $name-getValueCmd	"%W cget -text" \
@@ -93,7 +95,7 @@ namespace eval tablelist {
 	    $name-putListCmd	"" \
 	    $name-getListCmd	"" \
 	    $name-selectCmd	"" \
-	    $name-invokeCmd	"postMenubutton %W" \
+	    $name-invokeCmd	"event generate %W <Button-1>" \
 	    $name-fontOpt	-font \
 	    $name-useFormat	1 \
 	    $name-useReqWidth	0 \
@@ -108,7 +110,7 @@ namespace eval tablelist {
 	}
 
 	set name spinbox
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"$name %W -width 0" \
 	    $name-putValueCmd	"%W delete 0 end; %W insert 0 %T" \
 	    $name-getValueCmd	"%W get" \
@@ -130,12 +132,14 @@ namespace eval tablelist {
     addTkCoreWidgets 
 
     #
-    # Register the tile widgets ttk::entry, ttk::spinbox,
-    # ttk::combobox, and ttk::checkbutton for interactive cell editing
+    # Register the tile widgets ttk::entry, ttk::spinbox, ttk::combobox,
+    # ttk::checkbutton, and ttk::menubutton for interactive cell editing
     #
     proc addTileWidgets {} {
+	variable editWin
+
 	set name ttk::entry
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createTileEntry %W" \
 	    $name-putValueCmd	"%W delete 0 end; %W insert 0 %T" \
 	    $name-getValueCmd	"%W get" \
@@ -155,7 +159,7 @@ namespace eval tablelist {
 	]
 
 	set name ttk::spinbox
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createTileSpinbox %W" \
 	    $name-putValueCmd	"%W delete 0 end; %W insert 0 %T" \
 	    $name-getValueCmd	"%W get" \
@@ -175,7 +179,7 @@ namespace eval tablelist {
 	]
 
 	set name ttk::combobox
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createTileCombobox %W" \
 	    $name-putValueCmd	"%W set %T" \
 	    $name-getValueCmd	"%W get" \
@@ -195,7 +199,7 @@ namespace eval tablelist {
 	]
 
 	set name ttk::checkbutton
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createTileCheckbutton %W" \
 	    $name-putValueCmd	{set [%W cget -variable] %T} \
 	    $name-getValueCmd	{set [%W cget -variable]} \
@@ -215,7 +219,7 @@ namespace eval tablelist {
 	]
 
 	set name ttk::menubutton
-	array set ::tablelist::editWin [list \
+	array set editWin [list \
 	    $name-creationCmd	"createTileMenubutton %W" \
 	    $name-putValueCmd	{set [%W cget -textvariable] %T} \
 	    $name-getValueCmd	"%W cget -text" \
@@ -224,7 +228,7 @@ namespace eval tablelist {
 	    $name-putListCmd	"" \
 	    $name-getListCmd	"" \
 	    $name-selectCmd	"" \
-	    $name-invokeCmd	"event generate %W <space>" \
+	    $name-invokeCmd	"event generate %W <Button-1>" \
 	    $name-fontOpt	"" \
 	    $name-useFormat	1 \
 	    $name-useReqWidth	0 \
@@ -233,6 +237,10 @@ namespace eval tablelist {
 	    $name-focusWin	%W \
 	    $name-reservedKeys	{} \
 	]
+
+	foreach {name value} [array get editWin ttk::*-creationCmd] {
+	    set editWin(::$name) $value
+	}
     }
     if {$::tk_version >= 8.4 && [llength [package versions tile]] > 0} {
 	addTileWidgets 
@@ -253,7 +261,8 @@ namespace eval tablelist {
 proc tablelist::addBWidgetEntry {{name Entry}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"Entry %W -width 0" \
 	$name-putValueCmd	"%W delete 0 end; %W insert 0 %T" \
 	$name-getValueCmd	"%W get" \
@@ -284,7 +293,8 @@ proc tablelist::addBWidgetEntry {{name Entry}} {
 proc tablelist::addBWidgetSpinBox {{name SpinBox}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"SpinBox %W -editable 1 -width 0" \
 	$name-putValueCmd	"%W configure -text %T" \
 	$name-getValueCmd	"%W cget -text" \
@@ -315,8 +325,9 @@ proc tablelist::addBWidgetSpinBox {{name SpinBox}} {
 proc tablelist::addBWidgetComboBox {{name ComboBox}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
-	$name-creationCmd	"ComboBox %W -editable 1 -width 0" \
+    variable editWin
+    array set editWin [list \
+	$name-creationCmd	"createBWidgetComboBox %W" \
 	$name-putValueCmd	"%W configure -text %T" \
 	$name-getValueCmd	"%W cget -text" \
 	$name-putTextCmd	"%W configure -text %T" \
@@ -346,7 +357,8 @@ proc tablelist::addBWidgetComboBox {{name ComboBox}} {
 proc tablelist::addIncrEntryfield {{name entryfield}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"iwidgets::entryfield %W -width 0" \
 	$name-putValueCmd	"%W clear; %W insert 0 %T" \
 	$name-getValueCmd	"%W get" \
@@ -416,7 +428,8 @@ proc tablelist::addIncrDateTimeWidget {widgetType args} {
     }
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"iwidgets::$widgetType %W" \
 	$name-putValueCmd	"%W show %T" \
 	$name-getValueCmd	"%W get" \
@@ -434,13 +447,13 @@ proc tablelist::addIncrDateTimeWidget {widgetType args} {
 	$name-reservedKeys	{Left Right Up Down} \
     ]
     if {$useClicks} {
-	lappend ::tablelist::editWin($name-getValueCmd) -clicks
-	set ::tablelist::editWin($name-useFormat) 0
+	lappend editWin($name-getValueCmd) -clicks
+	set editWin($name-useFormat) 0
     }
     if {[string match "date*" $widgetType]} {
-	set ::tablelist::editWin($name-focusWin) {[%W component date]}
+	set editWin($name-focusWin) {[%W component date]}
     } else {
-	set ::tablelist::editWin($name-focusWin) {[%W component time]}
+	set editWin($name-focusWin) {[%W component time]}
     }
 
     return $name
@@ -455,7 +468,8 @@ proc tablelist::addIncrDateTimeWidget {widgetType args} {
 proc tablelist::addIncrSpinner {{name spinner}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"iwidgets::spinner %W -width 0" \
 	$name-putValueCmd	"%W clear; %W insert 0 %T" \
 	$name-getValueCmd	"%W get" \
@@ -486,7 +500,8 @@ proc tablelist::addIncrSpinner {{name spinner}} {
 proc tablelist::addIncrSpinint {{name spinint}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"iwidgets::spinint %W -width 0" \
 	$name-putValueCmd	"%W clear; %W insert 0 %T" \
 	$name-getValueCmd	"%W get" \
@@ -517,7 +532,8 @@ proc tablelist::addIncrSpinint {{name spinint}} {
 proc tablelist::addIncrCombobox {{name combobox}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"createIncrCombobox %W" \
 	$name-putValueCmd	"%W clear entry; %W insert entry 0 %T" \
 	$name-getValueCmd	"%W get" \
@@ -547,7 +563,8 @@ proc tablelist::addIncrCombobox {{name combobox}} {
 proc tablelist::addCtext {{name ctext}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"ctext %W -padx 2 -pady 2 -wrap none" \
 	$name-putValueCmd	"%W delete 1.0 end; %W insert 1.0 %T" \
 	$name-getValueCmd	"%W get 1.0 end-1c" \
@@ -579,7 +596,8 @@ proc tablelist::addCtext {{name ctext}} {
 proc tablelist::addOakleyCombobox {{name combobox}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"createOakleyCombobox %W" \
 	$name-putValueCmd	"%W delete 0 end; %W insert 0 %T" \
 	$name-getValueCmd	"%W get" \
@@ -688,7 +706,8 @@ proc tablelist::addDateMentry {fmt sep args} {
     }
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	[list mentry::dateMentry %W $fmt $sep] \
 	$name-putValueCmd	"mentry::putClockVal %T %W -gmt $useGMT" \
 	$name-getValueCmd	"mentry::getClockVal %W -gmt $useGMT" \
@@ -764,7 +783,8 @@ proc tablelist::addTimeMentry {fmt sep args} {
     }
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	[list mentry::timeMentry %W $fmt $sep] \
 	$name-putValueCmd	"mentry::putClockVal %T %W -gmt $useGMT" \
 	$name-getValueCmd	"mentry::getClockVal %W -gmt $useGMT" \
@@ -802,7 +822,7 @@ proc tablelist::addDateTimeMentry {fmt dateSep timeSep args} {
 		 fields(0) fields(1) fields(2) fields(3) fields(4) fields(5)]} {
 	return -code error \
 	       "bad format \"$fmt\": must be a string of length 5 or 6,\
-	        with the first 3 characters consisting of the letters d, m,\
+		with the first 3 characters consisting of the letters d, m,\
 		and y or Y, followed by H or I, then M, and optionally by S"
     }
 
@@ -857,7 +877,8 @@ proc tablelist::addDateTimeMentry {fmt dateSep timeSep args} {
     }
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	[list mentry::dateTimeMentry %W $fmt \
 				      $dateSep $timeSep] \
 	$name-putValueCmd	"mentry::putClockVal %T %W -gmt $useGMT" \
@@ -936,7 +957,8 @@ proc tablelist::addFixedPointMentry {cnt1 cnt2 args} {
     }
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	[list mentry::fixedPointMentry %W $cnt1 $cnt2] \
 	$name-putValueCmd	"mentry::putReal %T %W" \
 	$name-getValueCmd	"mentry::getReal %W" \
@@ -955,7 +977,7 @@ proc tablelist::addFixedPointMentry {cnt1 cnt2 args} {
 	$name-reservedKeys	{Left Right} \
     ]
     if {$useComma} {
-	lappend ::tablelist::editWin($name-creationCmd) -comma
+	lappend editWin($name-creationCmd) -comma
     }
 
     return $name
@@ -970,7 +992,8 @@ proc tablelist::addFixedPointMentry {cnt1 cnt2 args} {
 proc tablelist::addIPAddrMentry {{name ipAddrMentry}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"mentry::ipAddrMentry %W" \
 	$name-putValueCmd	"mentry::putIPAddr %T %W" \
 	$name-getValueCmd	"mentry::getIPAddr %W" \
@@ -1001,7 +1024,8 @@ proc tablelist::addIPAddrMentry {{name ipAddrMentry}} {
 proc tablelist::addIPv6AddrMentry {{name ipv6AddrMentry}} {
     checkEditWinName $name
 
-    array set ::tablelist::editWin [list \
+    variable editWin
+    array set editWin [list \
 	$name-creationCmd	"mentry::ipv6AddrMentry %W" \
 	$name-putValueCmd	"mentry::putIPv6Addr %T %W" \
 	$name-getValueCmd	"mentry::getIPv6Addr %W" \
@@ -1041,7 +1065,7 @@ proc tablelist::checkEditWinName name {
 	       "edit window name \"$name\" is reserved for Tk $name widgets"
     }
 
-    if {[regexp {^ttk::(entry|spinbox|combobox|checkbutton|menubutton)$} \
+    if {[regexp {^(::)?ttk::(entry|spinbox|combobox|checkbutton|menubutton)$} \
 	 $name]} {
 	return -code error \
 	       "edit window name \"$name\" is reserved for tile $name widgets"
@@ -1076,7 +1100,15 @@ proc tablelist::createCheckbutton {w args} {
 	    checkbutton $w -borderwidth 0 -font {"MS Sans Serif" 8} \
 			   -padx 0 -pady 0
 	    [winfo parent $w] configure -width 13 -height 13
-	    place $w -x -1 -y -1
+	    switch [winfo reqheight $w] {
+		17	{ set y -1 }
+		20	{ set y -3 }
+		25	{ set y -5 }
+		30 -
+		31	{ set y -8 }
+		default	{ set y -1 }
+	    }
+	    place $w -x -1 -y $y
 	}
 
 	classic {
@@ -1088,7 +1120,7 @@ proc tablelist::createCheckbutton {w args} {
 	aqua {
 	    checkbutton $w -borderwidth 0 -font "system" -padx 0 -pady 0
 	    [winfo parent $w] configure -width 16 -height 16
-	    place $w -x -4 -y -2
+	    place $w -x -4 -y -3
 	}
     }
 
@@ -1129,6 +1161,11 @@ proc tablelist::createMenubutton {w args} {
 
     set menu $w.menu
     menu $menu -tearoff 0 -postcommand [list tablelist::postMenuCmd $w]
+    foreach event {<Map> <Unmap>} {
+	bind $menu $event {
+	    tablelist::invokeMotionHandler [tablelist::getTablelistPath %W]
+	}
+    }
     if {[string compare $winSys "x11"] == 0} {
 	$menu configure -background $data(-background) \
 			-foreground $data(-foreground) \
@@ -1149,48 +1186,37 @@ proc tablelist::createMenubutton {w args} {
 #------------------------------------------------------------------------------
 proc tablelist::postMenuCmd w {
     set menu [$w cget -menu]
-    set last [$menu index last]
-    if {[string compare $last "none"] == 0} {
-	return ""
-    }
-
     variable winSys
     if {[string compare $winSys "x11"] == 0} {
-	set text [$w cget -text]
-	for {set idx 0} {$idx <= $last} {incr idx} {
-	    if {[string compare [$menu type $idx] "radiobutton"] == 0 &&
-		[string compare [$menu entrycget $idx -value] $text] == 0} {
-		$menu activate $idx
+	set last [$menu index last]
+	if {[string compare $last "none"] != 0} {
+	    set text [$w cget -text]
+	    for {set idx 0} {$idx <= $last} {incr idx} {
+		if {[string compare [$menu type $idx] "radiobutton"] == 0 &&
+		    [string compare [$menu entrycget $idx -value] $text] == 0} {
+		    $menu activate $idx
+		}
 	    }
 	}
-    } elseif {[string compare [winfo class $w] "TMenubutton"] == 0} {
-	if {[catch {set ::tk::Priv(popup) $menu}] != 0} {
-	    set ::tkPriv(popup) $menu
+    } else {
+	if {[catch {set ::tk::Priv(postedMb) ""}] != 0} {
+	    set ::tkPriv(postedMb) ""
 	}
-    }
-}
 
-#------------------------------------------------------------------------------
-# tablelist::postMenubutton
-#
-# Posts a menubutton widget used for interactive cell editing in a tablelist
-# widget.
-#------------------------------------------------------------------------------
-proc tablelist::postMenubutton w {
-    variable winSys
-    if {[string compare $winSys "x11"] == 0} {
-	event generate $w <space>
-	return ""
-    }
+	if {[string compare [winfo class $w] "TMenubutton"] == 0} {
+	    if {[catch {set ::tk::Priv(popup) $menu}] != 0} {
+		set ::tkPriv(popup) $menu
+	    }
+	}
 
-    if {[catch {
-	set ::tk::Priv(postedMb) ""
-	event generate $w <space>
-	set ::tk::Priv(postedMb) ""
-    }] != 0} {
-	set ::tkPriv(postedMb) ""
-	event generate $w <space>
-	set ::tkPriv(postedMb) ""
+	if {[string compare $winSys "aqua"] == 0} {
+	    set win [getTablelistPath $w]
+	    upvar ::tablelist::ns${win}::data data
+	    if {[string compare [$data(body) cget -cursor] $data(-cursor)]
+		!= 0} {
+		$data(body) configure -cursor $data(-cursor)
+	    }
+	}
     }
 }
 
@@ -1212,7 +1238,7 @@ proc tablelist::createTileEntry {w args} {
     # -borderwidth 2 setting, set the padding to another value.
     #
     set win [getTablelistPath $w]
-    switch [getCurrentTheme] {
+    switch -- [getCurrentTheme] {
 	aqua {
 	    set padding {0 0 0 -1}
 	}
@@ -1263,7 +1289,7 @@ proc tablelist::createTileSpinbox {w args} {
     # -borderwidth 2 setting, set the padding to another value.
     #
     set win [getTablelistPath $w]
-    switch [getCurrentTheme] {
+    switch -- [getCurrentTheme] {
 	aqua {
 	    set padding {0 0 0 -1}
 	}
@@ -1347,9 +1373,9 @@ proc tablelist::createTileCheckbutton {w args} {
     #
     set currentTheme [getCurrentTheme]
     if {[string compare $currentTheme "aqua"] == 0} {
-	catch { style layout Tablelist.TCheckbutton { Checkbutton.button } }
+	catch {style layout Tablelist.TCheckbutton { Checkbutton.button }}
     } else {
-	catch { style layout Tablelist.TCheckbutton { Checkbutton.indicator } }
+	catch {style layout Tablelist.TCheckbutton { Checkbutton.indicator }}
 	styleConfig Tablelist.TCheckbutton -indicatormargin 0
     }
 
@@ -1368,10 +1394,10 @@ proc tablelist::createTileCheckbutton {w args} {
     # Adjust the dimensions of the tile checkbutton's parent
     # and manage the checkbutton, depending on the current theme
     #
-    switch $currentTheme {
+    switch -- $currentTheme {
 	aqua {
-	    [winfo parent $w] configure -width 16 -height 17
-	    place $w -x -3 -y -2
+	    [winfo parent $w] configure -width 16 -height 16
+	    place $w -x -3 -y -3
 	}
 
 	Aquativo {
@@ -1522,6 +1548,23 @@ proc tablelist::createTileMenubutton {w args} {
     $w configure -menu $menu
 }
 
+#------------------------------------------------------------------------------
+# tablelist::createBWidgetComboBox
+#
+# Creates a BWidget ComboBox widget with the given path name for interactive
+# cell editing in a tablelist widget.
+#------------------------------------------------------------------------------
+proc tablelist::createBWidgetComboBox {w args} {
+    eval [list ComboBox $w -editable 1 -width 0] $args
+    ComboBox::_create_popup $w
+
+    foreach event {<Map> <Unmap>} {
+	bind $w.shell.listb $event {
+	    tablelist::invokeMotionHandler [tablelist::getTablelistPath %W]
+	}
+    }
+}
+
 #------------------------------------------------------------------------------
 # tablelist::createIncrCombobox
 #
@@ -1531,6 +1574,12 @@ proc tablelist::createTileMenubutton {w args} {
 proc tablelist::createIncrCombobox {w args} {
     eval [list iwidgets::combobox $w -dropdown 1 -editable 1 -width 0] $args
 
+    foreach event {<Map> <Unmap>} {
+	bind [$w component list] $event {+
+	    tablelist::invokeMotionHandler [tablelist::getTablelistPath %W]
+	}
+    }
+
     #
     # Make sure that the entry component will receive the input focus
     # whenever the list component (a scrolledlistbox widget) gets unmapped
@@ -1547,6 +1596,12 @@ proc tablelist::createIncrCombobox {w args} {
 proc tablelist::createOakleyCombobox {w args} {
     eval [list combobox::combobox $w -editable 1 -width 0] $args
 
+    foreach event {<Map> <Unmap>} {
+	bind $w.top.list $event {
+	    tablelist::invokeMotionHandler [tablelist::getTablelistPath %W]
+	}
+    }
+
     #
     # Repack the widget's components, to make sure that the
     # button will remain visible when shrinking the combobox.
@@ -1588,7 +1643,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 
     #
     # Create a frame to be embedded into the tablelist's body, together with
-    # a child of column-specific type; replace the binding tag Frame with
+    # a child of column/cell-specific type; replace the binding tag Frame with
     # $data(editwinTag) and TablelistEdit in the frame's list of binding tags
     #
     seeCell $win $row $col
@@ -1599,16 +1654,6 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 		 -highlightthickness 0 -relief flat -takefocus 0
     catch {$f configure -padx 0 -pady 0}
     bindtags $f [lreplace [bindtags $f] 1 1 $data(editwinTag) TablelistEdit]
-    bind $f <Destroy> {
-	array set tablelist::ns[winfo parent [winfo parent %W]]::data \
-		  {editKey ""  editRow -1  editCol -1}
-	if {[catch {tk::CancelRepeat}] != 0} {
-	    tkCancelRepeat 
-	}
-	if {[catch {ttk::CancelRepeat}] != 0} {
-	    catch {tile::CancelRepeat}
-	}
-    }
     set name [getEditWindow $win $row $col]
     variable editWin
     set creationCmd [strMap {"%W" "$w"} $editWin($name-creationCmd)]
@@ -1639,6 +1684,33 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	catch {$w configure -justify $alignment}
     }
 
+    #
+    # Define some bindings for the above frame
+    #
+    bind $f <Enter> {
+	set tablelist::W [tablelist::getTablelistPath %W]
+	set tablelist::ns${tablelist::W}::data(inEditWin) 1
+	tablelist::invokeMotionHandler $tablelist::W
+    }
+    bind $f <Leave> {
+	set tablelist::W [tablelist::getTablelistPath %W]
+	set tablelist::ns${tablelist::W}::data(inEditWin) 0
+	set tablelist::ns${tablelist::W}::data(prevCell) -1,-1
+	tablelist::invokeMotionHandler $tablelist::W
+    }
+    bind $f <Destroy> {
+	set tablelist::W [tablelist::getTablelistPath %W]
+	array set tablelist::ns${tablelist::W}::data \
+	      {editKey ""  editRow -1  editCol -1  inEditWin 0  prevCell -1,-1}
+	if {[catch {tk::CancelRepeat}] != 0} {
+	    tkCancelRepeat 
+	}
+	if {[catch {ttk::CancelRepeat}] != 0} {
+	    catch {tile::CancelRepeat}
+	}
+	tablelist::invokeMotionHandler $tablelist::W
+    }
+
     #
     # Replace the cell's contents between the two tabs with the above frame
     #
@@ -1722,9 +1794,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 
 	    variable winSys
 	    if {[string compare $winSys "aqua"] == 0} {
-		catch {
-		    set ::tk::mac::useCustomMDEF $data(useCustomMDEFSav)
-		}
+		catch {set ::tk::mac::useCustomMDEF $data(useCustomMDEFSav)}
 	    }
 
 	    if {$data(canceled)} {
@@ -1735,17 +1805,16 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 		eval [strMap {"%W" "$w"  "%T" "$text"} \
 		      $editWin($name-putValueCmd)]
 	    }
+	}
 
-	    if {$isMenubtn} {
-		set menu [$w cget -menu]
-		set last [$menu index last]
-		if {[string compare $last "none"] != 0} {
-		    set varName [$w cget -textvariable]
-		    for {set idx 0} {$idx <= $last} {incr idx} {
-			if {[string compare [$menu type $idx] "radiobutton"]
-			    == 0} {
-			    $menu entryconfigure $idx -variable $varName
-			}
+	if {$isMenubtn} {
+	    set menu [$w cget -menu]
+	    set last [$menu index last]
+	    if {[string compare $last "none"] != 0} {
+		set varName [$w cget -textvariable]
+		for {set idx 0} {$idx <= $last} {incr idx} {
+		    if {[string compare [$menu type $idx] "radiobutton"] == 0} {
+			$menu entryconfigure $idx -variable $varName
 		    }
 		}
 	    }
@@ -1822,6 +1891,67 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	}
     }
 
+    if {$data(-autofinishediting)} {
+	#
+	# Make sure that selecting a combobox or menu
+	# entry will automatically finish the editing
+	#
+	switch $class {
+	    TCombobox {
+		bind $w <<ComboboxSelected>> \
+		    {+ [tablelist::getTablelistPath %W] finishediting}
+	    }
+
+	    ComboBox {					;# BWidget
+		set cmd [$w cget -modifycmd]
+		$w configure -modifycmd [format {
+		    eval [list %s]
+		    after 0 [list %s finishediting]
+		} $cmd $win]
+	    }
+
+	    Combobox {					;# IWidgets or Oakley
+		if {[catch {$w cget -selectioncommand} cmd] == 0} {  ;# IWidgets
+		    set cmd [$w cget -selectioncommand]
+		    $w configure -selectioncommand [format {
+			eval [list %s]
+			after 0 [list %s finishediting]
+		    } $cmd $win]
+		} elseif {[catch {$w cget -command} cmd] == 0} {     ;# Oakley
+		    if {[string length $cmd] == 0} {
+			proc ::tablelist::comboboxCmd {w val} [format {
+			    after 0 [list %s finishediting]
+			} $win]
+		    } else {
+			proc ::tablelist::comboboxCmd {w val} [format {
+			    eval [list %s $w $val]
+			    after 0 [list %s finishediting]
+			} $cmd $win]
+		    }
+		    $w configure -command ::tablelist::comboboxCmd
+		}
+	    }
+
+	    Menubutton -
+	    TMenubutton {
+		set menu [$w cget -menu]
+		set last [$menu index last]
+		if {[string compare $last "none"] != 0} {
+		    for {set idx 0} {$idx <= $last} {incr idx} {
+			if {[regexp {^(command|checkbutton|radiobutton)$} \
+			     [$menu type $idx]]} {
+			    set cmd [$menu entrycget $idx -command]
+			    $menu entryconfigure $idx -command [format {
+				eval [list %s]
+				after 0 [list %s finishediting]
+			    } $cmd $win]
+			}
+		    }
+		}
+	    }
+	}
+    }
+
     #
     # Adjust the frame's height
     #
@@ -2483,11 +2613,15 @@ proc tablelist::defineTablelistEdit {} {
 	    if {!$tablelist::priv(clickedInEditWin)} {
 		if {$tablelist::priv(justClicked)} {
 		    tablelist::moveOrActivate $tablelist::W \
-			$tablelist::priv(row) $tablelist::priv(col)
+			$tablelist::priv(row) $tablelist::priv(col) 1
 		} else {
 		    tablelist::moveOrActivate $tablelist::W \
 			[$tablelist::W nearest       $tablelist::y] \
-			[$tablelist::W nearestcolumn $tablelist::x]
+			[$tablelist::W nearestcolumn $tablelist::x] \
+			[expr {$tablelist::x >= 0 &&
+			       $tablelist::x < [winfo width $tablelist::W] &&
+			       $tablelist::y >= [winfo y $tablelist::W.body] &&
+			       $tablelist::y < [winfo height $tablelist::W]}]
 		}
 	    }
 	    after 100 [list tablelist::condEvalInvokeCmd $tablelist::W]
@@ -2509,7 +2643,7 @@ proc tablelist::defineTablelistEdit {} {
 	    tablelist::finishEditing %W
 	}
     }
-    bind TablelistEdit <Tab>          { tablelist::goToNextPrevCell %W  1 }
+    bind TablelistEdit <Tab>	      { tablelist::goToNextPrevCell %W  1 }
     bind TablelistEdit <Shift-Tab>    { tablelist::goToNextPrevCell %W -1 }
     bind TablelistEdit <<PrevWindow>> { tablelist::goToNextPrevCell %W -1 }
     foreach modifier $modList {
@@ -2960,7 +3094,7 @@ proc tablelist::isKeyReserved {w keySym} {
 # one of its descendants, has mouse wheel bindings.
 #------------------------------------------------------------------------------
 proc tablelist::hasMouseWheelBindings w {
-    if {[string compare [winfo class $w] "TCombobox"] == 0} {
+    if {[regexp {^(Text|Ctext|TCombobox|TSpinbox)$} [winfo class $w]]} {
 	return 1
     } else {
 	set bindTags [bindtags $w]
